==> docker-model-1.2.0-sources.jar: annotations/io/fabric8/docker/api/model/StatsFluent.java <==
package io.fabric8.docker.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.docker.api.builder.Nested;
import java.lang.String;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import io.sundr.builder.annotations.Buildable;
import javax.annotation.Generated;
import io.fabric8.docker.api.builder.Fluent;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import javax.validation.Valid;
import java.lang.Object;
import lombok.ToString;
import java.util.Map;

public interface StatsFluent<A extends StatsFluent<A>> extends Fluent<A>{


    public BlkioStats getBlkioStats();
    public A withBlkioStats(BlkioStats blkioStats);
    public StatsFluent.BlkioStatsNested<A> withNewBlkioStats();
    public StatsFluent.BlkioStatsNested<A> withNewBlkioStatsLike(BlkioStats item);
    public StatsFluent.BlkioStatsNested<A> editBlkioStats();
    public StatsFluent.BlkioStatsNested<A> editOrNewBlkioStats();
    public StatsFluent.BlkioStatsNested<A> editOrNewBlkioStatsLike(BlkioStats item);
    public CPUStats getCpuStats();
    public A withCpuStats(CPUStats cpuStats);
    public StatsFluent.CpuStatsNested<A> withNewCpuStats();
    public StatsFluent.CpuStatsNested<A> withNewCpuStatsLike(CPUStats item);
    public StatsFluent.CpuStatsNested<A> editCpuStats();
    public StatsFluent.CpuStatsNested<A> editOrNewCpuStats();
    public StatsFluent.CpuStatsNested<A> editOrNewCpuStatsLike(CPUStats item);
    public MemoryStats getMemoryStats();
    public A withMemoryStats(MemoryStats memoryStats);
    public StatsFluent.MemoryStatsNested<A> withNewMemoryStats();
    public StatsFluent.MemoryStatsNested<A> withNewMemoryStatsLike(MemoryStats item);
    public StatsFluent.MemoryStatsNested<A> editMemoryStats();
    public StatsFluent.MemoryStatsNested<A> editOrNewMemoryStats();
    public StatsFluent.MemoryStatsNested<A> editOrNewMemoryStatsLike(MemoryStats item);
    public CPUStats getPrecpuStats();
    public A withPrecpuStats(CPUStats precpuStats);
    public StatsFluent.PrecpuStatsNested<A> withNewPrecpuStats();
    public StatsFluent.PrecpuStatsNested<A> withNewPrecpuStatsLike(CPUStats item);
    public StatsFluent.PrecpuStatsNested<A> editPrecpuStats();
    public StatsFluent.PrecpuStatsNested<A> editOrNewPrecpuStats();
    public StatsFluent.PrecpuStatsNested<A> editOrNewPrecpuStatsLike(CPUStats item);
    public String getRead();
    public A withRead(String read);

    public interface BlkioStatsNested<N> extends io.fabric8.docker.api.builder.Nested<N>,BlkioStatsFluent<StatsFluent.BlkioStatsNested<N>>{

        
    public N and();    public N endBlkioStats();
}
    public interface CpuStatsNested<N> extends io.fabric8.docker.api.builder.Nested<N>,CPUStatsFluent<StatsFluent.CpuStatsNested<N>>{

        
    public N and();    public N endCpuStats();
}
    public interface MemoryStatsNested<N> extends io.fabric8.docker.api.builder.Nested<N>,MemoryStatsFluent<StatsFluent.MemoryStatsNested<N>>{

        
    public N and();    public N endMemoryStats();
}
    public interface PrecpuStatsNested<N> extends io.fabric8.docker.api.builder.Nested<N>,CPUStatsFluent<StatsFluent.PrecpuStatsNested<N>>{

        
    public N and();    public N endPrecpuStats();
}


}

==> docker-model-1.2.2-sources.jar: annotations/io/fabric8/docker/api/model/StatsFluent.java <==
package io.fabric8.docker.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.docker.api.builder.Fluent;
import io.fabric8.docker.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface StatsFluent<A extends StatsFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildBlkioStats instead.
 */
@Deprecated public BlkioStats getBlkioStats();
    public BlkioStats buildBlkioStats();
    public A withBlkioStats(BlkioStats blkioStats);
    public Boolean hasBlkioStats();
    public StatsFluent.BlkioStatsNested<A> withNewBlkioStats();
    public StatsFluent.BlkioStatsNested<A> withNewBlkioStatsLike(BlkioStats item);
    public StatsFluent.BlkioStatsNested<A> editBlkioStats();
    public StatsFluent.BlkioStatsNested<A> editOrNewBlkioStats();
    public StatsFluent.BlkioStatsNested<A> editOrNewBlkioStatsLike(BlkioStats item);
    
/**
 * This method has been deprecated, please use method buildCpuStats instead.
 */
@Deprecated public CPUStats getCpuStats();
    public CPUStats buildCpuStats();
    public A withCpuStats(CPUStats cpuStats);
    public Boolean hasCpuStats();
    public StatsFluent.CpuStatsNested<A> withNewCpuStats();
    public StatsFluent.CpuStatsNested<A> withNewCpuStatsLike(CPUStats item);
    public StatsFluent.CpuStatsNested<A> editCpuStats();
    public StatsFluent.CpuStatsNested<A> editOrNewCpuStats();
    public StatsFluent.CpuStatsNested<A> editOrNewCpuStatsLike(CPUStats item);
    
/**
 * This method has been deprecated, please use method buildMemoryStats instead.
 */
@Deprecated public MemoryStats getMemoryStats();
    public MemoryStats buildMemoryStats();
    public A withMemoryStats(MemoryStats memoryStats);
    public Boolean hasMemoryStats();
    public StatsFluent.MemoryStatsNested<A> withNewMemoryStats();
    public StatsFluent.MemoryStatsNested<A> withNewMemoryStatsLike(MemoryStats item);
    public StatsFluent.MemoryStatsNested<A> editMemoryStats();
    public StatsFluent.MemoryStatsNested<A> editOrNewMemoryStats();
    public StatsFluent.MemoryStatsNested<A> editOrNewMemoryStatsLike(MemoryStats item);
    
/**
 * This method has been deprecated, please use method buildPrecpuStats instead.
 */
@Deprecated public CPUStats getPrecpuStats();
    public CPUStats buildPrecpuStats();
    public A withPrecpuStats(CPUStats precpuStats);
    public Boolean hasPrecpuStats();
    public StatsFluent.PrecpuStatsNested<A> withNewPrecpuStats();
    public StatsFluent.PrecpuStatsNested<A> withNewPrecpuStatsLike(CPUStats item);
    public StatsFluent.PrecpuStatsNested<A> editPrecpuStats();
    public StatsFluent.PrecpuStatsNested<A> editOrNewPrecpuStats();
    public StatsFluent.PrecpuStatsNested<A> editOrNewPrecpuStatsLike(CPUStats item);
    public String getRead();
    public A withRead(String read);
    public Boolean hasRead();

    public interface BlkioStatsNested<N> extends io.fabric8.docker.api.builder.Nested<N>,BlkioStatsFluent<StatsFluent.BlkioStatsNested<N>>{

        
    public N and();    public N endBlkioStats();
}
    public interface CpuStatsNested<N> extends io.fabric8.docker.api.builder.Nested<N>,CPUStatsFluent<StatsFluent.CpuStatsNested<N>>{

        
    public N and();    public N endCpuStats();
}
    public interface MemoryStatsNested<N> extends io.fabric8.docker.api.builder.Nested<N>,MemoryStatsFluent<StatsFluent.MemoryStatsNested<N>>{

        
    public N and();    public N endMemoryStats();
}
    public interface PrecpuStatsNested<N> extends io.fabric8.docker.api.builder.Nested<N>,CPUStatsFluent<StatsFluent.PrecpuStatsNested<N>>{

        
    public N and();    public N endPrecpuStats();
}


}
